@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # daemon/daemon.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,13 +5,9 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Daemon process behaviour.
-    """
-
-from __future__ import (absolute_import, unicode_literals)
+""" Daemon process behaviour. """
 
 import atexit
-import collections
 import errno
 import os
 import pwd
@@ -21,29 +15,12 @@ import resource
 import signal
 import socket
 import sys
-try:
-    # Python 2 has both ‘str’ (bytes) and ‘unicode’ (text).
-    basestring = basestring
-    unicode = unicode
-except NameError:
-    # Python 3 names the Unicode data type ‘str’.
-    basestring = str
-    unicode = str
-
-__metaclass__ = type
+import warnings
 
 
 class DaemonError(Exception):
     """ Base exception class for errors from this module. """
 
-    def __init__(self, *args, **kwargs):
-        self._chain_from_context()
-
-        super(DaemonError, self).__init__(*args, **kwargs)
-
-    def _chain_from_context(self):
-        _chain_exception_from_existing_exception_context(self, as_cause=True)
-
 
 class DaemonOSEnvironmentError(DaemonError, OSError):
     """ Exception raised when daemon OS environment setup receives error. """
@@ -230,7 +207,6 @@ class DaemonContext:
 
             If ``None``, the corresponding system stream is re-bound to the
             file named by `os.devnull`.
-
         """
 
     def __init__(
@@ -350,7 +326,6 @@ class DaemonContext:
 
             When the function returns, the running program is a daemon
             process.
-
             """
         if self.is_open:
             return
@@ -406,14 +381,13 @@ class DaemonContext:
 
             * Mark this instance as closed (for the purpose of future `open`
               and `close` calls).
-
             """
         if not self.is_open:
             return
 
         if self.pidfile is not None:
             # Follow the interface for telling a context manager to exit,
-            # <URL:http://docs.python.org/library/stdtypes.html#typecontextmanager>.
+            # <URL:https://docs.python.org/3/library/stdtypes.html#typecontextmanager>.
             self.pidfile.__exit__(None, None, None)
 
         self._is_open = False
@@ -434,7 +408,6 @@ class DaemonContext:
             following step:
 
             * Raise a ``SystemExit`` exception explaining the signal.
-
             """
         exception = SystemExit(
                 "Terminating on signal {signal_number!r}".format(
@@ -487,11 +460,10 @@ class DaemonContext:
             If `target` is ``None``, return ``signal.SIG_IGN``. If `target`
             is a text string, return the attribute of this instance named
             by that string. Otherwise, return `target` itself.
-
             """
         if target is None:
             result = signal.SIG_IGN
-        elif isinstance(target, basestring):
+        elif isinstance(target, str):
             name = target
             result = getattr(self, name)
         else:
@@ -507,7 +479,6 @@ class DaemonContext:
             Construct a map from signal numbers to handlers for this
             context instance, suitable for passing to
             `set_signal_handlers`.
-
             """
         signal_handler_map = dict(
                 (signal_number, self._make_signal_handler(target))
@@ -573,14 +544,13 @@ def change_working_directory(directory):
 
         :param directory: The target directory path.
         :return: ``None``.
-
         """
     try:
         os.chdir(directory)
     except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change working directory ({exc})".format(exc=exc))
-        raise error
+        raise error from exc
 
 
 def change_root_directory(directory):
@@ -592,7 +562,6 @@ def change_root_directory(directory):
         Set the current working directory, then the process root directory,
         to the specified `directory`. Requires appropriate OS privileges
         for this process.
-
         """
     try:
         os.chdir(directory)
@@ -600,7 +569,7 @@ def change_root_directory(directory):
     except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change root directory ({exc})".format(exc=exc))
-        raise error
+        raise error from exc
 
 
 def change_file_creation_mask(mask):
@@ -608,14 +577,13 @@ def change_file_creation_mask(mask):
 
         :param mask: The numeric file creation mask to set.
         :return: ``None``.
-
         """
     try:
         os.umask(mask)
     except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change file creation mask ({exc})".format(exc=exc))
-        raise error
+        raise error from exc
 
 
 def get_username_for_uid(uid):
@@ -646,7 +614,6 @@ def change_process_owner(uid, gid, initgroups=False):
         All these operations require appropriate OS privileges. If
         permission is denied, a ``DaemonOSEnvironmentError`` is
         raised.
-
         """
     try:
         username = get_username_for_uid(uid)
@@ -663,7 +630,7 @@ def change_process_owner(uid, gid, initgroups=False):
     except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change process owner ({exc})".format(exc=exc))
-        raise error
+        raise error from exc
 
 
 def prevent_core_dump():
@@ -673,7 +640,6 @@ def prevent_core_dump():
 
         Set the soft and hard limits for core dump size to zero. On Unix,
         this entirely prevents the process from creating core dump.
-
         """
     core_resource = resource.RLIMIT_CORE
 
@@ -685,7 +651,7 @@ def prevent_core_dump():
         error = DaemonOSEnvironmentError(
                 "System does not support RLIMIT_CORE resource limit"
                 " ({exc})".format(exc=exc))
-        raise error
+        raise error from exc
 
     # Set hard and soft limits to zero, i.e. no core dump at all.
     core_limit = (0, 0)
@@ -703,7 +669,6 @@ def detach_process_context():
         Reference: “Advanced Programming in the Unix Environment”,
         section 13.3, by W. Richard Stevens, published 1993 by
         Addison-Wesley.
-
         """
 
     def fork_then_exit_parent(error_message):
@@ -713,7 +678,6 @@ def detach_process_context():
                 detach failure.
             :return: ``None``.
             :raise DaemonProcessDetachError: If the fork fails.
-
             """
         try:
             pid = os.fork()
@@ -723,7 +687,7 @@ def detach_process_context():
             error = DaemonProcessDetachError(
                     "{message}: [{exc.errno:d}] {exc.strerror}".format(
                         message=error_message, exc=exc))
-            raise error
+            raise error from exc
 
     fork_then_exit_parent(error_message="Failed first fork")
     os.setsid()
@@ -737,7 +701,6 @@ def is_process_started_by_init():
             ``False``.
 
         The `init` process is the one with process ID of 1.
-
         """
     result = False
 
@@ -757,13 +720,49 @@ def is_socket(fd):
 
         Query the socket type of `fd`. If there is no error, the file is a
         socket.
+        """
+    warnings.warn(
+            DeprecationWarning("migrate to `is_socket_file` instead"))
 
+    result = False
+
+    try:
+        file_socket = socket.fromfd(fd, socket.AF_INET, socket.SOCK_RAW)
+        file_socket.getsockopt(socket.SOL_SOCKET, socket.SO_TYPE)
+    except socket.error as exc:
+        exc_errno = exc.args[0]
+        if exc_errno == errno.ENOTSOCK:
+            # Socket operation on non-socket.
+            pass
+        else:
+            # Some other socket error.
+            result = True
+    else:
+        # No error getting socket type.
+        result = True
+
+    return result
+
+
+def is_socket_file(file):
+    """ Determine whether the `file` is a socket.
+
+        :param file: The file (an `io.IOBase` instance) to interrogate.
+        :return: ``True`` iff `file` is a socket; otherwise ``False``.
+
+        Query the socket type of the file descriptor of `file`. If there is no
+        error, the file is a socket.
         """
     result = False
 
-    file_socket = socket.fromfd(fd, socket.AF_INET, socket.SOCK_RAW)
+    try:
+        file_fd = file.fileno()
+    except ValueError:
+        # The file doesn't have a file descriptor.
+        file_fd = None
 
     try:
+        file_socket = socket.fromfd(file_fd, socket.AF_INET, socket.SOCK_RAW)
         file_socket.getsockopt(socket.SOL_SOCKET, socket.SO_TYPE)
     except socket.error as exc:
         exc_errno = exc.args[0]
@@ -790,12 +789,10 @@ def is_process_started_by_superserver():
         attaches it to the standard streams of the child process. If
         that is the case for this process, return ``True``, otherwise
         ``False``.
-
         """
     result = False
 
-    stdin_fd = sys.__stdin__.fileno()
-    if is_socket(stdin_fd):
+    if is_socket_file(sys.__stdin__):
         result = True
 
     return result
@@ -815,7 +812,6 @@ def is_detach_process_context_required():
 
         If any of the above are true, the process is deemed to be already
         detached.
-
         """
     result = True
     if is_process_started_by_init() or is_process_started_by_superserver():
@@ -832,7 +828,6 @@ def close_file_descriptor_if_open(fd):
 
         Close the file descriptor `fd`, suppressing an error in the
         case the file was not open.
-
         """
     try:
         os.close(fd)
@@ -844,11 +839,12 @@ def close_file_descriptor_if_open(fd):
             error = DaemonOSEnvironmentError(
                     "Failed to close file descriptor {fd:d} ({exc})".format(
                         fd=fd, exc=exc))
-            raise error
+            raise error from exc
 
 
 MAXFD = 2048
 
+
 def get_maximum_file_descriptors():
     """ Get the maximum number of open file descriptors for this process.
 
@@ -858,7 +854,6 @@ def get_maximum_file_descriptors():
         The maximum is the process hard resource limit of maximum number of
         open file descriptors. If the limit is “infinity”, a default value
         of ``MAXFD`` is returned.
-
         """
     (__, hard_limit) = resource.getrlimit(resource.RLIMIT_NOFILE)
 
@@ -869,6 +864,10 @@ def get_maximum_file_descriptors():
     return result
 
 
+_total_file_descriptor_range = (0, get_maximum_file_descriptors())
+_total_file_descriptor_set = set(range(*_total_file_descriptor_range))
+
+
 def _get_candidate_file_descriptors(exclude):
     """ Get the collection of candidate file descriptors.
 
@@ -885,15 +884,10 @@ def _get_candidate_file_descriptors(exclude):
         The `maxfd` value is determined from the standard library
         `resource` module.
         """
-    maxfd = get_maximum_file_descriptors()
-    candidates = set(range(0, maxfd)).difference(exclude)
+    candidates = _total_file_descriptor_set.difference(exclude)
     return candidates
 
 
-FileDescriptorRange = collections.namedtuple(
-        'FileDescriptorRange', ['low', 'high'])
-
-
 def _get_candidate_file_descriptor_ranges(exclude):
     """ Get the collection of candidate file descriptor ranges.
 
@@ -912,35 +906,42 @@ def _get_candidate_file_descriptor_ranges(exclude):
         """
     candidates_list = sorted(_get_candidate_file_descriptors(exclude))
     ranges = []
-    this_range = FileDescriptorRange(
-            low=min(candidates_list),
-            high=(min(candidates_list) + 1))
+
+    def append_range_if_needed(candidate_range):
+        (low, high) = candidate_range
+        if (low < high):
+            # The range is not empty.
+            ranges.append(candidate_range)
+
+    this_range = (
+        (min(candidates_list), (min(candidates_list) + 1))
+        if candidates_list else (0, 0))
     for fd in candidates_list[1:]:
         high = fd + 1
-        if this_range.high == fd:
+        if this_range[1] == fd:
             # This file descriptor extends the current range.
-            this_range = this_range._replace(high=high)
+            this_range = (this_range[0], high)
         else:
             # The previous range has ended at a gap.
-            ranges.append(this_range)
+            append_range_if_needed(this_range)
             # This file descriptor begins a new range.
-            this_range = FileDescriptorRange(low=fd, high=high)
-    ranges.append(this_range)
+            this_range = (fd, high)
+    append_range_if_needed(this_range)
     return ranges
 
 
 def _close_file_descriptor_ranges(ranges):
     """ Close file descriptors described by `ranges`.
 
-        :param ranges: A sequence of `FileDescriptorRange` instances,
-            each describing a range of file descriptors to close.
+        :param ranges: A sequence of tuples `(low, high)`, each
+            describing a range of file descriptors to close.
         :return: ``None``.
 
         Attempt to close each open file descriptor – starting from
         `low` and ending before `high` – from each range in `ranges`.
         """
     for range in ranges:
-        os.closerange(range.low, range.high)
+        os.closerange(range[0], range[1])
 
 
 def close_all_open_files(exclude=None):
@@ -975,7 +976,6 @@ def redirect_stream(system_stream, target_stream):
 
         If `target_stream` is ``None``, defaults to opening the
         operating system's null device and using its file descriptor.
-
         """
     if target_stream is None:
         target_fd = os.open(os.devnull, os.O_RDWR)
@@ -991,7 +991,6 @@ def make_default_signal_map():
 
         The signals available differ by system. The map will not contain
         any signals not defined on the running system.
-
         """
     name_map = {
             'SIGTSTP': None,
@@ -1016,7 +1015,6 @@ def set_signal_handlers(signal_handler_map):
 
         See the `signal` module for details on signal numbers and signal
         handlers.
-
         """
     for (signal_number, handler) in signal_handler_map.items():
         signal.signal(signal_number, handler)
@@ -1030,35 +1028,11 @@ def register_atexit_function(func):
 
         The function `func` is registered for a call with no arguments
         at program exit.
-
         """
     atexit.register(func)
 
 
-def _chain_exception_from_existing_exception_context(exc, as_cause=False):
-    """ Decorate the specified exception with the existing exception context.
-
-        :param exc: The exception instance to decorate.
-        :param as_cause: If true, the existing context is declared to be
-            the cause of the exception.
-        :return: ``None``.
-
-        :PEP:`344` describes syntax and attributes (`__traceback__`,
-        `__context__`, `__cause__`) for use in exception chaining.
-
-        Python 2 does not have that syntax, so this function decorates
-        the exception with values from the current exception context.
-
-        """
-    (existing_exc_type, existing_exc, existing_traceback) = sys.exc_info()
-    if as_cause:
-        exc.__cause__ = existing_exc
-    else:
-        exc.__context__ = existing_exc
-    exc.__traceback__ = existing_traceback
-
-
-# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
 # Copyright © 2007–2008 Robert Niederreiter, Jens Klein
 # Copyright © 2004–2005 Chad J. Schroeder
 # Copyright © 2003 Clark Evans
