@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # daemon/runner.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,10 +5,7 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Daemon runner library.
-    """
-
-from __future__ import (absolute_import, unicode_literals)
+""" Daemon runner library. """
 
 import errno
 import os
@@ -21,22 +16,7 @@ import warnings
 import lockfile
 
 from . import pidfile
-from .daemon import (
-        _chain_exception_from_existing_exception_context,
-        DaemonContext,
-        basestring,
-        unicode,
-)
-
-
-try:
-    # Python 3 standard library.
-    ProcessLookupError
-except NameError:
-    # No such class in Python 2.
-    ProcessLookupError = NotImplemented
-
-__metaclass__ = type
+from .daemon import DaemonContext
 
 
 warnings.warn(
@@ -47,22 +27,10 @@ warnings.warn(
 class DaemonRunnerError(Exception):
     """ Abstract base class for errors from DaemonRunner. """
 
-    def __init__(self, *args, **kwargs):
-        self._chain_from_context()
-
-        super(DaemonRunnerError, self).__init__(*args, **kwargs)
-
-    def _chain_from_context(self):
-        _chain_exception_from_existing_exception_context(self, as_cause=True)
-
 
 class DaemonRunnerInvalidActionError(DaemonRunnerError, ValueError):
     """ Raised when specified action for DaemonRunner is invalid. """
 
-    def _chain_from_context(self):
-        # This exception is normally not caused by another.
-        _chain_exception_from_existing_exception_context(self, as_cause=False)
-
 
 class DaemonRunnerStartFailureError(DaemonRunnerError, RuntimeError):
     """ Raised when failure starting DaemonRunner. """
@@ -80,7 +48,6 @@ class DaemonRunner:
         * 'start': Become a daemon and call `app.run()`.
         * 'stop': Exit the daemon process specified in the PID file.
         * 'restart': Stop, then start.
-
         """
 
     start_message = "started with pid {pid:d}"
@@ -106,7 +73,6 @@ class DaemonRunner:
 
             * `run`: Callable that will be invoked when the daemon is
               started.
-
             """
         self.parse_args()
         self.app = app
@@ -140,7 +106,6 @@ class DaemonRunner:
             :param argv: The command-line arguments used to invoke the
                 program, as a sequence of strings.
             :return: ``None``.
-
             """
         progname = os.path.basename(argv[0])
         usage_exit_code = 2
@@ -163,7 +128,6 @@ class DaemonRunner:
 
             If the parser fails to parse the arguments, emit a usage
             message and exit the program.
-
             """
         if argv is None:
             argv = sys.argv
@@ -172,7 +136,7 @@ class DaemonRunner:
         if len(argv) < min_args:
             self._usage_exit(argv)
 
-        self.action = unicode(argv[1])
+        self.action = str(argv[1])
         if self.action not in self.action_funcs:
             self._usage_exit(argv)
 
@@ -182,18 +146,17 @@ class DaemonRunner:
             :return: ``None``.
             :raises DaemonRunnerStartFailureError: If the PID file cannot
                 be locked by this process.
-
             """
         if is_pidfile_stale(self.pidfile):
             self.pidfile.break_lock()
 
         try:
             self.daemon_context.open()
-        except lockfile.AlreadyLocked:
+        except lockfile.AlreadyLocked as exc:
             error = DaemonRunnerStartFailureError(
                     "PID file {pidfile.path!r} already locked".format(
                         pidfile=self.pidfile))
-            raise error
+            raise error from exc
 
         pid = os.getpid()
         message = self.start_message.format(pid=pid)
@@ -207,7 +170,6 @@ class DaemonRunner:
             :return: ``None``.
             :raises DaemonRunnerStopFailureError: If terminating the daemon
                 fails with an OS error.
-
             """
         pid = self.pidfile.read_pid()
         try:
@@ -216,7 +178,7 @@ class DaemonRunner:
             error = DaemonRunnerStopFailureError(
                     "Failed to terminate {pid:d}: {exc}".format(
                         pid=pid, exc=exc))
-            raise error
+            raise error from exc
 
     def _stop(self):
         """ Exit the daemon process specified in the current PID file.
@@ -224,7 +186,6 @@ class DaemonRunner:
             :return: ``None``.
             :raises DaemonRunnerStopFailureError: If the PID file is not
                 already locked.
-
             """
         if not self.pidfile.is_locked():
             error = DaemonRunnerStopFailureError(
@@ -238,8 +199,7 @@ class DaemonRunner:
             self._terminate_daemon_process()
 
     def _restart(self):
-        """ Stop, then start.
-            """
+        """ Stop, then start. """
         self._stop()
         self._start()
 
@@ -259,7 +219,6 @@ class DaemonRunner:
 
             The action is specified by the `action` attribute, which is set
             during `parse_args`.
-
             """
         try:
             func = self.action_funcs[self.action]
@@ -277,7 +236,6 @@ class DaemonRunner:
 
             The action is specified by the `action` attribute, which is set
             during `parse_args`.
-
             """
         func = self._get_action_func()
         func(self)
@@ -293,7 +251,7 @@ def emit_message(message, stream=None):
 
 def make_pidlockfile(path, acquire_timeout):
     """ Make a PIDLockFile instance with the given filesystem path. """
-    if not isinstance(path, basestring):
+    if not isinstance(path, str):
         error = ValueError("Not a filesystem path: {path!r}".format(
                 path=path))
         raise error
@@ -313,7 +271,6 @@ def is_pidfile_stale(pidfile):
 
         The PID file is “stale” if its contents are valid but do not
         match the PID of a currently-running process.
-
         """
     result = False
 
@@ -324,16 +281,11 @@ def is_pidfile_stale(pidfile):
         except ProcessLookupError:
             # The specified PID does not exist.
             result = True
-        except OSError as exc:
-            if exc.errno == errno.ESRCH:
-                # Under Python 2, process lookup error is an OSError.
-                # The specified PID does not exist.
-                result = True
 
     return result
 
 
-# Copyright © 2009–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2009–2021 Ben Finney <ben+python@benfinney.id.au>
 # Copyright © 2007–2008 Robert Niederreiter, Jens Klein
 # Copyright © 2003 Clark Evans
 # Copyright © 2002 Noah Spurrier
