@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # test/__init__.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,13 +5,10 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Unit test suite for ‘daemon’ package.
-    """
-
-from __future__ import (absolute_import, unicode_literals)
+""" Unit test suite for ‘daemon’ package. """
 
 
-# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
