@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # test/scaffold.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,10 +5,7 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Scaffolding for unit test modules.
-    """
-
-from __future__ import (absolute_import, unicode_literals)
+""" Scaffolding for unit test modules. """
 
 from copy import deepcopy
 import doctest
@@ -19,15 +14,6 @@ import logging
 import operator
 import textwrap
 
-try:
-    # Python 2 has both ‘str’ (bytes) and ‘unicode’ (text).
-    basestring = basestring
-    unicode = unicode
-except NameError:
-    # Python 3 names the Unicode data type ‘str’.
-    basestring = str
-    unicode = str
-
 import testscenarios
 import testtools.testcase
 
@@ -50,16 +36,9 @@ def get_function_signature(func):
         * 'arg_defaults': A sequence of the default values for the arguments.
         * 'var_args': The name bound to remaining positional arguments.
         * 'var_kw_args': The name bound to remaining keyword arguments.
-
         """
-    try:
-        # Python 3 function attributes.
-        func_code = func.__code__
-        func_defaults = func.__defaults__
-    except AttributeError:
-        # Python 2 function attributes.
-        func_code = func.func_code
-        func_defaults = func.func_defaults
+    func_code = func.__code__
+    func_defaults = func.__defaults__
 
     arg_count = func_code.co_argcount
     arg_names = func_code.co_varnames[:arg_count]
@@ -99,7 +78,6 @@ def format_function_signature(func):
         The signature is rendered as text; for example::
 
             foo(spam, eggs, ham=True, beans=None, *args, **kwargs)
-
         """
     signature = get_function_signature(func)
 
@@ -141,7 +119,6 @@ class TestCase(testtools.testcase.TestCase):
             a ``doctest.OutputChecker`` instance. This is not an equality
             check, but a pattern match according to the ``OutputChecker``
             rules.
-
             """
         checker = doctest.OutputChecker()
         want = textwrap.dedent(want)
@@ -177,7 +154,6 @@ class TestCase(testtools.testcase.TestCase):
 
             Fail the test if the function ``function`` is not at any of the
             levels in the traceback object ``traceback``.
-
             """
         func_in_traceback = False
         expected_code = function.func_code
@@ -226,7 +202,6 @@ class TestCase(testtools.testcase.TestCase):
             * collector for arbitrary positional arguments,
 
             * collector for arbitrary keyword arguments.
-
             """
         first_signature = get_function_signature(first)
         second_signature = get_function_signature(second)
@@ -291,7 +266,6 @@ def make_exception_scenarios(scenarios):
             :key types:
                 Sequence of types that should be superclasses of each
                 instance of the exception type.
-
         """
     updated_scenarios = deepcopy(scenarios)
     for (name, scenario) in updated_scenarios:
@@ -303,7 +277,7 @@ def make_exception_scenarios(scenarios):
     return updated_scenarios
 
 
-# Copyright © 2007–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2007–2022 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
