@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # test/test_metadata.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,33 +5,24 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Unit test for ‘_metadata’ private module.
-    """
-
-from __future__ import (absolute_import, unicode_literals)
+""" Unit test for ‘_metadata’ private module. """
 
 import collections
 import errno
 import functools
 import json
 import re
-try:
-    # Python 3 standard library.
-    import urllib.parse as urlparse
-except ImportError:
-    # Python 2 standard library.
-    import urlparse
-
 import unittest.mock
+import urllib.parse as urlparse
+
 import pkg_resources
 import testtools.helpers
 import testtools.matchers
 
-from . import scaffold
-from .scaffold import unicode
-
 import daemon._metadata as metadata
 
+from . import scaffold
+
 
 class HasAttribute(testtools.matchers.Matcher):
     """ A matcher to assert an object has a named attribute. """
@@ -44,7 +33,7 @@ class HasAttribute(testtools.matchers.Matcher):
     def match(self, instance):
         """ Assert the object `instance` has an attribute named `name`. """
         result = None
-        if not testtools.helpers.safe_hasattr(instance, self.attribute_name):
+        if not hasattr(instance, self.attribute_name):
             result = AttributeNotFoundMismatch(instance, self.attribute_name)
         return result
 
@@ -131,7 +120,7 @@ class YearRange_TestCase(scaffold.TestCaseWithScenarios):
 
     def test_text_representation_as_expected(self):
         """ Text representation should be as expected. """
-        result = unicode(self.test_instance)
+        result = str(self.test_instance)
         self.assertEqual(result, self.expected_text)
 
 
@@ -217,12 +206,6 @@ class metadata_content_TestCase(scaffold.TestCase):
                     url=metadata.url))
 
 
-try:
-    FileNotFoundError
-except NameError:
-    # Python 2 uses IOError.
-    FileNotFoundError = functools.partial(IOError, errno.ENOENT)
-
 version_info_filename = "version_info.json"
 
 
@@ -271,7 +254,8 @@ def fake_func_get_distribution(
     if (fake_distribution is None):
         fake_resources = {}
         if hasattr(testcase, 'test_version_info'):
-            fake_resources['version_info_filename'] = testcase.test_version_info
+            fake_resources['version_info_filename'] = (
+                testcase.test_version_info)
         fake_distribution = make_mock_distribution(
                 name=name,
                 metadata_resources=fake_resources)
@@ -415,9 +399,13 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
                 'expected_resource_name': "lorem_ipsum.json",
                 'expected_version_info': {'version': "1.0"},
                 }),
-            ('not installed', {
-                'get_distribution_error': pkg_resources.DistributionNotFound(),
-                'expected_version_info': default_version_info,
+            ('no distribution', {
+                'test_distribution': None,
+                'expected_version_info': {
+                    'release_date': "UNKNOWN",
+                    'version': "UNKNOWN",
+                    'maintainer': "UNKNOWN",
+                    },
                 }),
             ('no version_info', {
                 'expected_version_info': default_version_info,
@@ -438,8 +426,6 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
 
         self.mock_distribution_name = "mock-dist"
         patch_metadata_distribution_name(testcase=self)
-        self.mock_distribution = make_mock_distribution(
-                metadata.distribution_name, metadata_resources=None)
 
         self.test_args = {}
         if hasattr(self, 'test_filename'):
@@ -458,18 +444,18 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
                         self.test_version_info)
             self.test_metadata_resources = resources
 
-        self.mock_distribution = make_mock_distribution(
-                name=metadata.distribution_name,
-                metadata_resources=self.test_metadata_resources)
-        self.test_args['distribution'] = getattr(
-                self, 'test_distribution', self.mock_distribution)
+        if not hasattr(self, 'test_distribution'):
+            self.test_distribution = make_mock_distribution(
+                    metadata.distribution_name,
+                    metadata_resources=self.test_metadata_resources)
+        self.test_args['distribution'] = self.test_distribution
 
     def test_requests_specified_filename(self):
         """ The specified metadata resource name should be requested. """
-        if hasattr(self, 'get_distribution_error'):
-            self.skipTest("No access to distribution")
+        if self.test_distribution is None:
+            self.skipTest("No distribution specified")
         metadata.get_distribution_version_info(**self.test_args)
-        self.mock_distribution.has_metadata.assert_called_with(
+        self.test_distribution.has_metadata.assert_called_with(
                 self.expected_resource_name)
 
     def test_result_matches_expected_items(self):
@@ -478,7 +464,7 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
         self.assertEqual(self.expected_version_info, version_info)
 
 
-# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
