@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # test/test_pidfile.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,31 +5,23 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Unit test for ‘pidfile’ module.
-    """
+""" Unit test for ‘pidfile’ module. """
 
-from __future__ import (absolute_import, unicode_literals)
-
-try:
-    # Python 3 standard library.
-    import builtins
-except ImportError:
-    # Python 2 standard library.
-    import __builtin__ as builtins
+import builtins
 import errno
 import functools
 import io
 import itertools
 import os
 import tempfile
+import unittest.mock
 
 import lockfile
-import mock
-
-from . import scaffold
 
 import daemon.pidfile
 
+from . import scaffold
+
 
 class FakeFileDescriptorStringIO(io.StringIO, object):
     """ A StringIO class that fakes a file descriptor. """
@@ -40,7 +30,7 @@ class FakeFileDescriptorStringIO(io.StringIO, object):
 
     def __init__(self, *args, **kwargs):
         self._fileno = next(self._fileno_generator)
-        super(FakeFileDescriptorStringIO, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def fileno(self):
         return self._fileno
@@ -52,15 +42,6 @@ class FakeFileDescriptorStringIO(io.StringIO, object):
         pass
 
 
-try:
-    FileNotFoundError
-    PermissionError
-except NameError:
-    # Python 2 uses IOError.
-    FileNotFoundError = functools.partial(IOError, errno.ENOENT)
-    PermissionError = functools.partial(IOError, errno.EPERM)
-
-
 def make_pidlockfile_scenarios():
     """ Make a collection of scenarios for testing `PIDLockFile` instances.
 
@@ -69,7 +50,6 @@ def make_pidlockfile_scenarios():
 
         The collection is a mapping from scenario name to a dictionary of
         scenario attributes.
-
         """
 
     fake_current_pid = 235
@@ -155,7 +135,6 @@ def setup_pidfile_fixtures(testcase):
 
         Decorate the `testcase` with attributes to be fixtures for tests
         involving `PIDLockFile` instances.
-
         """
     scenarios = make_pidlockfile_scenarios()
     testcase.pidlockfile_scenarios = scenarios
@@ -168,7 +147,7 @@ def setup_pidfile_fixtures(testcase):
             pass
         return value
 
-    func_patcher_os_getpid = mock.patch.object(
+    func_patcher_os_getpid = unittest.mock.patch.object(
             os, "getpid",
             return_value=scenarios['simple']['pid'])
     func_patcher_os_getpid.start()
@@ -242,10 +221,10 @@ def setup_pidfile_fixtures(testcase):
             result = FakeFileDescriptorStringIO()
         return result
 
-    mock_open = mock.mock_open()
+    mock_open = unittest.mock.mock_open()
     mock_open.side_effect = fake_open
 
-    func_patcher_builtin_open = mock.patch.object(
+    func_patcher_builtin_open = unittest.mock.patch.object(
             builtins, "open",
             new=mock_open)
     func_patcher_builtin_open.start()
@@ -261,9 +240,9 @@ def setup_pidfile_fixtures(testcase):
             result = FakeFileDescriptorStringIO().fileno()
         return result
 
-    mock_os_open = mock.MagicMock(side_effect=fake_os_open)
+    mock_os_open = unittest.mock.MagicMock(side_effect=fake_os_open)
 
-    func_patcher_os_open = mock.patch.object(
+    func_patcher_os_open = unittest.mock.patch.object(
             os, "open",
             new=mock_os_open)
     func_patcher_os_open.start()
@@ -276,9 +255,9 @@ def setup_pidfile_fixtures(testcase):
             raise OSError(errno.EBADF, "Bad file descriptor")
         return result
 
-    mock_os_fdopen = mock.MagicMock(side_effect=fake_os_fdopen)
+    mock_os_fdopen = unittest.mock.MagicMock(side_effect=fake_os_fdopen)
 
-    func_patcher_os_fdopen = mock.patch.object(
+    func_patcher_os_fdopen = unittest.mock.patch.object(
             os, "fdopen",
             new=mock_os_fdopen)
     func_patcher_os_fdopen.start()
@@ -293,7 +272,6 @@ def make_lockfile_method_fakes(scenario):
             fake function.
 
         Each fake function behaves appropriately for the specified `scenario`.
-
         """
 
     def fake_func_read_pid():
@@ -324,7 +302,7 @@ def make_lockfile_method_fakes(scenario):
     fake_methods = dict(
             (
                 func_name.replace('fake_func_', ''),
-                mock.MagicMock(side_effect=fake_func))
+                unittest.mock.MagicMock(side_effect=fake_func))
             for (func_name, fake_func) in vars().items()
             if func_name.startswith('fake_func_'))
 
@@ -342,7 +320,6 @@ def apply_lockfile_method_mocks(mock_lockfile, testcase, scenario):
         Mock the `LockFile` methods of `mock_lockfile`, by applying fake
         methods customised for `scenario`. The mock is does by a patch
         within the context of `testcase`.
-
         """
     fake_methods = dict(
             (func_name, fake_func)
@@ -351,7 +328,7 @@ def apply_lockfile_method_mocks(mock_lockfile, testcase, scenario):
             if func_name not in ['read_pid'])
 
     for (func_name, fake_func) in fake_methods.items():
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 mock_lockfile, func_name,
                 new=fake_func)
         func_patcher.start()
@@ -366,7 +343,6 @@ def setup_pidlockfile_fixtures(testcase, scenario_name=None):
 
         Decorate the `testcase` with attributes that are fixtures for test
         cases involving `PIDLockFile` instances.`
-
         """
 
     setup_pidfile_fixtures(testcase)
@@ -375,7 +351,8 @@ def setup_pidlockfile_fixtures(testcase, scenario_name=None):
             'write_pid_to_pidfile',
             'remove_existing_pidfile',
             ]:
-        func_patcher = mock.patch.object(lockfile.pidlockfile, func_name)
+        func_patcher = unittest.mock.patch.object(
+                lockfile.pidlockfile, func_name)
         func_patcher.start()
         testcase.addCleanup(func_patcher.stop)
 
@@ -385,17 +362,11 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(TimeoutPIDLockFile_TestCase, self).setUp()
+        super().setUp()
 
         pidlockfile_scenarios = make_pidlockfile_scenarios()
         self.pidlockfile_scenario = pidlockfile_scenarios['simple']
 
-        for func_name in ['__init__', 'acquire']:
-            func_patcher = mock.patch.object(
-                    lockfile.pidlockfile.PIDLockFile, func_name)
-            func_patcher.start()
-            self.addCleanup(func_patcher.stop)
-
         self.scenario = {
                 'pidfile_path': self.pidlockfile_scenario['pidfile_path'],
                 'acquire_timeout': self.getUniqueInteger(),
@@ -427,7 +398,7 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
         expected_timeout = self.test_kwargs['acquire_timeout']
         self.assertEqual(expected_timeout, instance.acquire_timeout)
 
-    @mock.patch.object(
+    @unittest.mock.patch.object(
             lockfile.pidlockfile.PIDLockFile, "__init__",
             autospec=True)
     def test_calls_superclass_init(self, mock_init):
@@ -436,7 +407,7 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
         instance = daemon.pidfile.TimeoutPIDLockFile(**self.test_kwargs)
         mock_init.assert_called_with(instance, expected_path)
 
-    @mock.patch.object(
+    @unittest.mock.patch.object(
             lockfile.pidlockfile.PIDLockFile, "acquire",
             autospec=True)
     def test_acquire_uses_specified_timeout(self, mock_func_acquire):
@@ -447,7 +418,7 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
         instance.acquire(test_timeout)
         mock_func_acquire.assert_called_with(instance, expected_timeout)
 
-    @mock.patch.object(
+    @unittest.mock.patch.object(
             lockfile.pidlockfile.PIDLockFile, "acquire",
             autospec=True)
     def test_acquire_uses_stored_timeout_by_default(self, mock_func_acquire):
@@ -461,7 +432,7 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
         mock_func_acquire.assert_called_with(instance, expected_timeout)
 
 
-# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
