@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # test/test_runner.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -7,29 +5,24 @@
 # certain conditions; see the end of this file for copyright
 # information, grant of license, and disclaimer of warranty.
 
-""" Unit test for ‘runner’ module.
-    """
+""" Unit test for ‘runner’ module. """
 
-from __future__ import (absolute_import, unicode_literals)
-
-try:
-    # Python 3 standard library.
-    import builtins
-except ImportError:
-    # Python 2 standard library.
-    import __builtin__ as builtins
+import builtins
 import errno
 import functools
 import os
 import os.path
 import signal
 import sys
+import unittest.mock
 
 import lockfile
-import mock
+
+import daemon.daemon
+import daemon.pidfile
+import daemon.runner
 
 from . import scaffold
-from .scaffold import unicode
 from .test_daemon import (
         setup_streams_fixtures,
         )
@@ -40,10 +33,6 @@ from .test_pidfile import (
         setup_pidfile_fixtures,
         )
 
-import daemon.daemon
-import daemon.pidfile
-import daemon.runner
-
 
 class ModuleExceptions_TestCase(scaffold.Exception_TestCase):
     """ Test cases for module exception classes. """
@@ -80,7 +69,6 @@ def make_runner_scenarios():
 
         The collection is a mapping from scenario name to a dictionary of
         scenario attributes.
-
         """
 
     pidlockfile_scenarios = make_pidlockfile_scenarios()
@@ -114,7 +102,6 @@ def set_runner_scenario(testcase, scenario_name):
 
         Set the `DaemonRunner` test scenario name and decorate the
         `testcase` with the corresponding scenario fixtures.
-
         """
     scenarios = testcase.runner_scenarios
     testcase.scenario = scenarios[scenario_name]
@@ -131,14 +118,13 @@ def setup_runner_fixtures(testcase):
 
         Decorate the `testcase` with attributes to be fixtures for tests
         involving `DaemonRunner` instances.
-
         """
     setup_pidfile_fixtures(testcase)
     setup_streams_fixtures(testcase)
 
     testcase.runner_scenarios = make_runner_scenarios()
 
-    patcher_stderr = mock.patch.object(
+    patcher_stderr = unittest.mock.patch.object(
             sys, "stderr",
             new=FakeFileDescriptorStringIO())
     testcase.fake_stderr = patcher_stderr.start()
@@ -146,7 +132,7 @@ def setup_runner_fixtures(testcase):
 
     simple_scenario = testcase.runner_scenarios['simple']
 
-    testcase.mock_runner_lockfile = mock.MagicMock(
+    testcase.mock_runner_lockfile = unittest.mock.MagicMock(
             spec=daemon.pidfile.TimeoutPIDLockFile)
     apply_lockfile_method_mocks(
             testcase.mock_runner_lockfile,
@@ -154,13 +140,13 @@ def setup_runner_fixtures(testcase):
             simple_scenario['pidlockfile_scenario'])
     testcase.mock_runner_lockfile.path = simple_scenario['pidfile_path']
 
-    patcher_lockfile_class = mock.patch.object(
+    patcher_lockfile_class = unittest.mock.patch.object(
             daemon.pidfile, "TimeoutPIDLockFile",
             return_value=testcase.mock_runner_lockfile)
     patcher_lockfile_class.start()
     testcase.addCleanup(patcher_lockfile_class.stop)
 
-    class TestApp(object):
+    class TestApp:
 
         def __init__(self):
             self.stdin_path = testcase.stream_file_paths['stdin']
@@ -169,11 +155,11 @@ def setup_runner_fixtures(testcase):
             self.pidfile_path = simple_scenario['pidfile_path']
             self.pidfile_timeout = simple_scenario['pidfile_timeout']
 
-        run = mock.MagicMock(name="TestApp.run")
+        run = unittest.mock.MagicMock(name="TestApp.run")
 
     testcase.TestApp = TestApp
 
-    patcher_runner_daemoncontext = mock.patch.object(
+    patcher_runner_daemoncontext = unittest.mock.patch.object(
             daemon.runner, "DaemonContext", autospec=True)
     patcher_runner_daemoncontext.start()
     testcase.addCleanup(patcher_runner_daemoncontext.stop)
@@ -198,20 +184,20 @@ def setup_runner_fixtures(testcase):
         result.buffering = buffering
         return result
 
-    mock_open = mock.mock_open()
+    mock_open = unittest.mock.mock_open()
     mock_open.side_effect = fake_open
 
-    func_patcher_builtin_open = mock.patch.object(
+    func_patcher_builtin_open = unittest.mock.patch.object(
             builtins, "open",
             new=mock_open)
     func_patcher_builtin_open.start()
     testcase.addCleanup(func_patcher_builtin_open.stop)
 
-    func_patcher_os_kill = mock.patch.object(os, "kill")
+    func_patcher_os_kill = unittest.mock.patch.object(os, "kill")
     func_patcher_os_kill.start()
     testcase.addCleanup(func_patcher_os_kill.stop)
 
-    patcher_sys_argv = mock.patch.object(
+    patcher_sys_argv = unittest.mock.patch.object(
             sys, "argv",
             new=testcase.valid_argv_params['start'])
     patcher_sys_argv.start()
@@ -227,7 +213,7 @@ class DaemonRunner_BaseTestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(DaemonRunner_BaseTestCase, self).setUp()
+        super().setUp()
 
         setup_runner_fixtures(self)
         set_runner_scenario(self, 'simple')
@@ -238,9 +224,9 @@ class DaemonRunner_TestCase(DaemonRunner_BaseTestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(DaemonRunner_TestCase, self).setUp()
+        super().setUp()
 
-        func_patcher_parse_args = mock.patch.object(
+        func_patcher_parse_args = unittest.mock.patch.object(
                 daemon.runner.DaemonRunner, "parse_args")
         func_patcher_parse_args.start()
         self.addCleanup(func_patcher_parse_args.stop)
@@ -382,9 +368,9 @@ class DaemonRunner_parse_args_TestCase(DaemonRunner_BaseTestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(DaemonRunner_parse_args_TestCase, self).setUp()
+        super().setUp()
 
-        func_patcher_usage_exit = mock.patch.object(
+        func_patcher_usage_exit = unittest.mock.patch.object(
                 daemon.runner.DaemonRunner, "_usage_exit",
                 side_effect=NotImplementedError)
         func_patcher_usage_exit.start()
@@ -413,7 +399,7 @@ class DaemonRunner_parse_args_TestCase(DaemonRunner_BaseTestCase):
         instance = self.test_instance
         expected_action = 'start'
         argv = self.valid_argv_params['start']
-        with mock.patch.object(sys, "argv", new=argv):
+        with unittest.mock.patch.object(sys, "argv", new=argv):
             instance.parse_args()
         self.assertEqual(expected_action, instance.action)
 
@@ -426,13 +412,6 @@ class DaemonRunner_parse_args_TestCase(DaemonRunner_BaseTestCase):
             self.assertEqual(expected_action, instance.action)
 
 
-try:
-    ProcessLookupError
-except NameError:
-    # Python 2 uses OSError.
-    ProcessLookupError = functools.partial(OSError, errno.ESRCH)
-
-
 class DaemonRunner_do_action_TestCase(DaemonRunner_BaseTestCase):
     """ Test cases for DaemonRunner.do_action method. """
 
@@ -451,7 +430,7 @@ class DaemonRunner_do_action_start_TestCase(DaemonRunner_BaseTestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(DaemonRunner_do_action_start_TestCase, self).setUp()
+        super().setUp()
 
         self.test_instance.action = 'start'
 
@@ -466,7 +445,7 @@ class DaemonRunner_do_action_start_TestCase(DaemonRunner_BaseTestCase):
         exc = self.assertRaises(
                 expected_error,
                 instance.do_action)
-        self.assertIn(expected_message_content, unicode(exc))
+        self.assertIn(expected_message_content, str(exc))
 
     def test_breaks_lock_if_no_such_process(self):
         """ Should request breaking lock if PID file process not running. """
@@ -511,7 +490,7 @@ class DaemonRunner_do_action_stop_TestCase(DaemonRunner_BaseTestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(DaemonRunner_do_action_stop_TestCase, self).setUp()
+        super().setUp()
 
         set_runner_scenario(self, 'pidfile-locked')
 
@@ -536,7 +515,7 @@ class DaemonRunner_do_action_stop_TestCase(DaemonRunner_BaseTestCase):
         exc = self.assertRaises(
                 expected_error,
                 instance.do_action)
-        self.assertIn(expected_message_content, unicode(exc))
+        self.assertIn(expected_message_content, str(exc))
 
     def test_breaks_lock_if_pidfile_stale(self):
         """ Should break lock if PID file is stale. """
@@ -559,23 +538,28 @@ class DaemonRunner_do_action_stop_TestCase(DaemonRunner_BaseTestCase):
         instance = self.test_instance
         test_pid = self.scenario['pidlockfile_scenario']['pidfile_pid']
         test_error = OSError(errno.EPERM, "Nice try")
-        os.kill.side_effect = test_error
+
+        def fake_os_kill(pid, sig):
+            if (sig == signal.SIGTERM):
+                raise test_error
+        os.kill.side_effect = fake_os_kill
+
         expected_error = daemon.runner.DaemonRunnerStopFailureError
-        expected_message_content = unicode(test_pid)
+        expected_message_content = str(test_pid)
         exc = self.assertRaises(
                 expected_error,
                 instance.do_action)
-        self.assertIn(expected_message_content, unicode(exc))
+        self.assertIn(expected_message_content, str(exc))
 
 
-@mock.patch.object(daemon.runner.DaemonRunner, "_start")
-@mock.patch.object(daemon.runner.DaemonRunner, "_stop")
+@unittest.mock.patch.object(daemon.runner.DaemonRunner, "_start")
+@unittest.mock.patch.object(daemon.runner.DaemonRunner, "_stop")
 class DaemonRunner_do_action_restart_TestCase(DaemonRunner_BaseTestCase):
     """ Test cases for DaemonRunner.do_action method, action 'restart'. """
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(DaemonRunner_do_action_restart_TestCase, self).setUp()
+        super().setUp()
 
         set_runner_scenario(self, 'pidfile-locked')
 
@@ -591,7 +575,7 @@ class DaemonRunner_do_action_restart_TestCase(DaemonRunner_BaseTestCase):
         mock_func_daemonrunner_stop.assert_called_with()
 
 
-@mock.patch.object(sys, "stderr")
+@unittest.mock.patch.object(sys, "stderr")
 class emit_message_TestCase(scaffold.TestCase):
     """ Test cases for ‘emit_message’ function. """
 
@@ -605,15 +589,15 @@ class emit_message_TestCase(scaffold.TestCase):
     def test_writes_to_specified_stream(self, mock_stderr):
         """ Should write message to specified stream. """
         test_message = self.getUniqueString()
-        mock_stream = mock.MagicMock()
+        mock_stream = unittest.mock.MagicMock()
         daemon.runner.emit_message(test_message, stream=mock_stream)
-        mock_stream.write.assert_called_with(mock.ANY)
+        mock_stream.write.assert_called_with(unittest.mock.ANY)
 
     def test_writes_to_stderr_by_default(self, mock_stderr):
         """ Should write message to ‘sys.stderr’ by default. """
         test_message = self.getUniqueString()
         daemon.runner.emit_message(test_message)
-        mock_stderr.write.assert_called_with(mock.ANY)
+        mock_stderr.write.assert_called_with(unittest.mock.ANY)
 
 
 class is_pidfile_stale_TestCase(scaffold.TestCase):
@@ -621,15 +605,16 @@ class is_pidfile_stale_TestCase(scaffold.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(is_pidfile_stale_TestCase, self).setUp()
+        super().setUp()
 
-        func_patcher_os_kill = mock.patch.object(os, "kill")
+        func_patcher_os_kill = unittest.mock.patch.object(os, "kill")
         func_patcher_os_kill.start()
         self.addCleanup(func_patcher_os_kill.stop)
         os.kill.return_value = None
 
         self.test_pid = self.getUniqueInteger()
-        self.test_pidfile = mock.MagicMock(daemon.pidfile.TimeoutPIDLockFile)
+        self.test_pidfile = unittest.mock.MagicMock(
+                daemon.pidfile.TimeoutPIDLockFile)
         self.test_pidfile.read_pid.return_value = self.test_pid
 
     def test_returns_false_if_no_pid_in_file(self):
@@ -655,7 +640,7 @@ class is_pidfile_stale_TestCase(scaffold.TestCase):
         self.assertEqual(expected_result, result)
 
 
-# Copyright © 2009–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2009–2022 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
