@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # version.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
@@ -19,13 +17,10 @@
 
     Requires:
 
-    * Docutils <http://docutils.sourceforge.net/>
+    * Docutils <https://docutils.sourceforge.io/>
     * JSON <https://docs.python.org/3/reference/json.html>
-
     """
 
-from __future__ import (absolute_import, unicode_literals)
-
 import collections
 import datetime
 import distutils
@@ -46,17 +41,6 @@ import textwrap
 import setuptools
 import setuptools.command.egg_info
 
-try:
-    # Python 2 has both ‘str’ (bytes) and ‘unicode’ (text).
-    basestring = basestring
-    unicode = unicode
-except NameError:
-    # Python 3 names the Unicode data type ‘str’.
-    basestring = str
-    unicode = str
-
-__metaclass__ = type
-
 
 def ensure_class_bases_begin_with(namespace, class_name, base_class):
     """ Ensure the named class's bases start with the base class.
@@ -73,7 +57,6 @@ def ensure_class_bases_begin_with(namespace, class_name, base_class):
 
         Call this function after ensuring `base_class` is available,
         before using the class named by `class_name`.
-
         """
     existing_class = namespace[class_name]
     assert isinstance(existing_class, type)
@@ -134,7 +117,6 @@ def parse_person_field(value):
 
         If the `value` does not match a standard person with email
         address, the `email` item is ``None``.
-
         """
     result = ParsedPerson(None, None)
 
@@ -187,7 +169,6 @@ class ChangeLogEntry:
             :param value: The prospective `release_date` value.
             :return: ``None`` if the value is valid.
             :raises ValueError: If the value is invalid.
-
             """
         if value in ["UNKNOWN", "FUTURE"]:
             # A valid non-date value.
@@ -203,7 +184,6 @@ class ChangeLogEntry:
             :param vaue: The prospective `version` value.
             :return: ``None`` if the value is valid.
             :raises ValueError: If the value is invalid.
-
             """
         if value in ["UNKNOWN", "NEXT"]:
             # A valid non-version value.
@@ -222,7 +202,6 @@ class ChangeLogEntry:
             :param value: The prospective `maintainer` value.
             :return: ``None`` if the value is valid.
             :raises ValueError: If the value is invalid.
-
             """
         valid = False
 
@@ -300,9 +279,9 @@ class VersionInfoTranslator(object):
     bullet_text = "* "
 
     attr_convert_funcs_by_attr_name = {
-            'released': ('release_date', unicode),
-            'version': ('version', unicode),
-            'maintainer': ('maintainer', unicode),
+            'released': ('release_date', str),
+            'version': ('version', str),
+            'maintainer': ('maintainer', str),
             }
 
     def __init__(self, document):
@@ -452,7 +431,6 @@ def changelog_to_version_info_collection(infile):
 
         :param infile: A file-like object containing the changelog.
         :return: The serialised JSON data of the version info collection.
-
         """
 
     # Docutils is not available when Setuptools needs this module, so
@@ -496,7 +474,6 @@ def generate_version_info_from_changelog(infile_path):
             file cannot be read.
 
         The document is explicitly opened as UTF-8 encoded text.
-
         """
     version_info = collections.OrderedDict()
 
@@ -522,7 +499,6 @@ def get_latest_version(versions):
         :param versions: A collection of mappings for changelog entries.
         :return: An ordered mapping of fields for the latest version,
             if `versions` is non-empty; otherwise, an empty mapping.
-
         """
     version_info = collections.OrderedDict()
 
@@ -542,7 +518,6 @@ def serialise_version_info_from_mapping(version_info):
 
         :param version_info: Mapping of version info items.
         :return: The version info serialised to JSON.
-
         """
     content = json.dumps(version_info, indent=4)
 
@@ -559,7 +534,6 @@ def get_changelog_path(distribution, filename=changelog_filename):
         :param filename: The base filename of the changelog document.
         :return: Filesystem path of the changelog document, or ``None``
             if not discoverable.
-
         """
     build_py_command = distutils.command.build_py.build_py(distribution)
     build_py_command.finalize_options()
@@ -649,7 +623,6 @@ class ChangelogAwareDistribution(distutils.dist.Distribution, object):
         * version
         * maintainer
         * maintainer_email
-
         """
 
     __metaclass__ = type
@@ -689,7 +662,7 @@ class ChangelogAwareDistribution(distutils.dist.Distribution, object):
         return person.email
 
 
-# Copyright © 2008–2019 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2022 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
